pub struct ExportedNestEggVariable {
pub name: CompactString,
pub name_translations: BTreeMap<CompactString, CompactString>,
pub description: Option<CompactString>,
pub description_translations: BTreeMap<CompactString, CompactString>,
pub order: i16,
pub env_variable: CompactString,
pub default_value: Option<String>,
pub user_viewable: bool,
pub user_editable: bool,
pub secret: bool,
pub rules: Vec<CompactString>,
}Fields
name: CompactStringname_translations: BTreeMap<CompactString, CompactString>description: Option<CompactString>description_translations: BTreeMap<CompactString, CompactString>order: i16env_variable: CompactStringdefault_value: Option<String>user_viewable: booluser_editable: boolsecret: boolrules: Vec<CompactString>Trait Implementations
Sourceimpl Clone for ExportedNestEggVariable
impl Clone for ExportedNestEggVariable
Sourcefn clone(&self) -> ExportedNestEggVariable
fn clone(&self) -> ExportedNestEggVariable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExportedNestEggVariable
impl ComposeSchema for ExportedNestEggVariable
Sourceimpl<'de> Deserialize<'de> for ExportedNestEggVariable
impl<'de> Deserialize<'de> for ExportedNestEggVariable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ExportedNestEggVariable
impl Serialize for ExportedNestEggVariable
Sourceimpl ToSchema for ExportedNestEggVariable
impl ToSchema for ExportedNestEggVariable
Sourceimpl Validate for ExportedNestEggVariable
impl Validate for ExportedNestEggVariable
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for ExportedNestEggVariable
impl RefUnwindSafe for ExportedNestEggVariable
impl Send for ExportedNestEggVariable
impl Sync for ExportedNestEggVariable
impl Unpin for ExportedNestEggVariable
impl UnsafeUnpin for ExportedNestEggVariable
impl UnwindSafe for ExportedNestEggVariable